<# 	
	************************************************************************************************************
	Copyright (c) Microsoft Corporation.  All rights reserved.
	
	Version: 	1.0
	
	Purpose:	Install Microsoft Deploymnet Toolkit 2013
	************************************************************************************************************
#>


Function Check-Internet
{
    While (([Activator]::CreateInstance([Type]::GetTypeFromCLSID([Guid]{DCB00C01-570F-4A9B-8D69-199FDBA5723B})).IsConnectedToInternet) -eq $False)
    {
        Write-Host "No internet connection detected. Retrying in 60 seconds..."
        Start-Sleep -Seconds 60
    }
}

Function DownloadFile
{  
    param(
        [Parameter(Mandatory=$true)]
        [String] $url,
        [Parameter(Mandatory=$false)]
        [String] $localFile = (Join-Path $pwd.Path $url.SubString($url.LastIndexOf('/'))) 
    )
    
    begin {
	    $client = New-Object System.Net.WebClient
        $Global:downloadComplete = $false

        $eventDataComplete = Register-ObjectEvent $client DownloadFileCompleted `
            -SourceIdentifier WebClient.DownloadFileComplete `
            -Action {$Global:downloadComplete = $true}

        $eventDataProgress = Register-ObjectEvent $client DownloadProgressChanged `
            -SourceIdentifier WebClient.DownloadProgressChanged `
            -Action { $Global:DPCEventArgs = $EventArgs }    
    }

    process {
        Write-Progress -Activity 'Downloading file' -Status $url
        $client.DownloadFileAsync($url, $localFile)
    
        while (!($Global:downloadComplete)) {                
            $pc = $Global:DPCEventArgs.ProgressPercentage
            if ($pc -ne $null) {
                Write-Progress -Activity 'Downloading file' -Status $url -PercentComplete $pc
            }
        }
    
        Write-Progress -Activity 'Downloading file' -Status $url -Complete
    }

    end {
        Unregister-Event -SourceIdentifier WebClient.DownloadProgressChanged
        Unregister-Event -SourceIdentifier WebClient.DownloadFileComplete
        $client.Dispose()
        $Global:downloadComplete = $null
        $Global:DPCEventArgs = $null
        Remove-Variable client
        Remove-Variable eventDataComplete
        Remove-Variable eventDataProgress
        [GC]::Collect()    
    }
}  

# *****************************************************************************
# MAIN()
# *****************************************************************************
# Common Processing
# *****************************************************************************

$ScriptFolder = Split-Path -parent $MyInvocation.MyCommand.Definition
$SourceFile = "$ScriptFolder\source\MicrosoftDeploymentToolkit2013_x64.msi"
$InstallArguments =  '  /q /l*v C:\Windows\temp\INSTALL-MDT-App.log'
$InstalledProducts = Get-WmiObject Win32_Product
$MDT = $InstalledProducts | Where-Object {($_.Name -like "*Microsoft Deployment*") -and ($_.Version -eq "6.2.5019.0")}

If ($MDT -eq $null)
{
    If ((test-Path -Path $SourceFile))
    { 
	    Write-Host "Found  Installation files for MDT 2013"
	    $SourceFilePath = $(get-item $SourceFile).FullName
    }	
    Else 
    {
	    Write-Host "Downloading MDT"
        $URL = "http://download.microsoft.com/download/B/F/5/BF5DF779-ED74-4BEC-A07E-9EB25694C6BB/MicrosoftDeploymentToolkit2013_x64.msi"
        $Path = "$env:TEMP\MicrosoftDeploymentToolkit2013_x64.msi"
        Check-Internet
        DownloadFile $URL $Path
        $SourceFilePath = $(Get-Item $Path).FullName
    }
    try 
    {
            Write-Host "Installing Microsoft Deployment Toolkit"
	        Start-Process -file  $SourceFilePath -arg $InstallArguments -passthru | wait-process
	        Write-Host  "$AppName - INSTALLATION SUCCESSFULLY COMPLETED" 

	    }
	    catch 
        {

	        Write-Host  "$AppName - INSTALLATION ERROR (ERRORLEVEL=%ERRORLEVEL%)"
    }
}
Else
{
    Write-Host "MDT is already installed."
}
Exit
