

' // ***************************************************************************
' // 
' // Copyright (c) Microsoft Corporation.  All rights reserved.
' // 
' // Surface Deployment Accelerator
' //
' // File:      SDA_SupportRoutines.vbs
' // 
' // Version:   1.0
' // 
' // Purpose:   Provide supporting functions for the Surface Accelerator 
'//				Wizard
' // 
' // ***************************************************************************


Option Explicit
Dim sValidateUNC
Dim sValidateDomain
Dim bDoNotSaveParameters
Dim bLeaveShareOpen
Dim objWizardActions
Set objWizardActions = CreateObject ("Scripting.Dictionary")


Function LA_AgreeOnClick	
	if (SDA_LAAGREE.Checked = True) Then
		SDA_LAAGREE.Disabled = True
		buttonNext.Disabled = False
	End If	
End Function

Function RunSystemCheck
	Dim Buffer
	Dim strMDTDir
	Dim strMDTVer
	Dim strPSDir
    Dim strPSPol
	Dim oFSO
	Dim oReg
	Dim sKeyExistx86
	Dim sKeyExistx64
	Dim sKeyValue
	Dim strKeyPathx86
	Dim strKeyPathx64
	Dim StrADKVer
	Dim strMDTSPVer
	Dim objShell
	Dim sPoShCmd
	Dim iCheck
	Set oFSO = CreateObject("Scripting.FileSystemObject")
	Set objShell = CreateObject("Wscript.shell")
	On Error Resume Next	

	' Set powershell execution policy to RemoteSigned
	sPoShCmd = """Set-ExecutionPolicy Bypass -force ;exit $LastExitCode"""
	iCheck = objShell.run("powershell -executionpolicy bypass -noprofile -command " & sPoShCmd,0,1)
	If (iCheck = 0) Then
		oLogging.CreateEntry "PowerShell execution policy set to Bypass", LogTypeInfo
		AddToList Buffer, "VALIDATED - PowerShell execution policy set to Bypass.", vbNewLine
	Else
		oLogging.CreateEntry "PowerShell execution policy set to Bypass", LogTypeInfo
		AddToList Buffer, "VALIDATED - PowerShell execution policy set to Bypass.", vbNewLine
	End If

	oLogging.CreateEntry "***REQUIREMENTS VALIDATION STARTED***", LogTypeInfo
	' Check if the Windows ADk for Windows 8.1 with Update is installed
	sPoShCmd = """if ((Get-ItemProperty HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\* | Where-Object {($_.DisplayName -eq 'Windows Deployment Tools') -and ($_.DisplayVersion -ge '8.100.26866')}) -ne $Null){Write-Host 'Installed';Exit 11} else {Write-Host 'Install';Exit 10};exit $LastExitCode"""
	iCheck = objShell.run("powershell -executionpolicy bypass -noprofile -command " & sPoShCmd,0,1)
	If (iCheck = 11) Then
		oLogging.CreateEntry "Windows ADK x64 installation validated", LogTypeInfo
		AddToList Buffer, "VALIDATED - Windows Assessment and Deployment Kit.", vbNewLine
		oEnvironment.Item("ADK_INSTALL") = "NO"
	Else
		oLogging.CreateEntry "Windows ADK x64 installation required", LogTypeInfo
		AddToList Buffer, "---> REQUIRED - Windows Assessment and Deployment Kit.", vbNewLine
		oEnvironment.Item("ADK_INSTALL") = "YES"
	End If
	
	' Check if MDT 2013 is installed. MDT 2013 Update 1 is explicitly exlcuded for now
	sPoShCmd = """if ((Get-ItemProperty HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\* | Where-Object {($_.DisplayName -like 'Microsoft Deployment Toolkit*') -and ($_.DisplayVersion -eq '6.2.5019.0')}) -ne $Null){Write-Host 'Installed';Exit 11} else {Write-Host 'Install';Exit 10};exit $LastExitCode"""
	iCheck = objShell.run("powershell -executionpolicy bypass -noprofile -command " & sPoShCmd,0,1)
	If (iCheck = 11) Then
		oLogging.CreateEntry "MDT 2013 installation validated", LogTypeInfo
		AddToList Buffer, "VALIDATED - Microsoft Deployment Toolkit 2013.", vbNewLine
		oEnvironment.Item("MDT_INSTALL") = "NO"
	Else
		oLogging.CreateEntry "MDT 2013 installation required. MDT 2013 Update 1 is not supported.", LogTypeInfo
		AddToList Buffer, "---> REQUIRED - MDT 2013.  MDT 2013 Update 1 is not supported.", vbNewLine
		oEnvironment.Item("MDT_INSTALL") = "YES"
	End If
	
	strPSDir = outility.RegRead("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\PowerShell\1\ShellIds\Microsoft.PowerShell\Path")
	strPSVer = outility.RegRead("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\PowerShell\1\PowerShellEngine\PowerShellVersion")
	strPSPol = outility.RegRead ("HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\PowerShell\1\ShellIds\Microsoft.PowerShell\ExecutionPolicy")				
	SDA_SystemAssessment.InnerText = Buffer
	On Error Goto 0
End function

Function DeviceSupport
	If (cbSurface_Firmware.Checked) Then
		oEnvironment.Item("Surface_Firmware") = "YES"
	Else
		oEnvironment.Item("Surface_Firmware") = "NO"
	End If
	If (cbSurface_App.Checked) Then
		oEnvironment.Item("Surface_App") = "YES"
	Else
		oEnvironment.Item("Surface_App") = "NO"
	End If	
	If (cbSurfacePro3_Drivers.Checked) Then
		oEnvironment.Item("SurfacePro3_Drivers") = "YES"
	Else
		oEnvironment.Item("SurfacePro3_Drivers") = "NO"
	End If
	DeviceSupport = TRUE
End Function

Function DeploymentShare
	oEnvironment.Item("DSFILEPATH") = SDA_DeployFolder.Value
	oEnvironment.Item("DSSHARENAME") = SDA_DeployShare.Value
	If (cbConfigWDS.Checked) Then
		oEnvironment.Item("WDS_CONFIG") = "YES"
	Else
		oEnvironment.Item("WDS_CONFIG") = "NO"
	End If
	DeploymentShare = TRUE
End Function

Function OSSourceFiles
	If (Trim(SDA_OSSourceFolder.Value) <> "") Then
		oEnvironment.Item("OSSOURCEFILEPATH") = SDA_OSSourceFolder.Value
		OSSourceFiles = True
	Else
		OSSourceFiles = False
	End If
	
End Function

Function UserCredentialsInitialize
	Dim oArguments
	Dim SWbemObject
	Dim sNewDomain
	Dim aUNCPath

	' Parse the Command Line

	sValidateDomain = oUtility.Arguments.Item("ValidateAgainstDomain")
	aUNCPath = Split(oUtility.Arguments.Item("ValidateAgainstUNCPath"),"\")
	bDoNotSaveParameters = oUtility.Arguments.Exists("DoNotSave")
	bLeaveShareOpen = oUtility.Arguments.Exists("LeaveShareOpen")

	oEnvironment.Item("UserCredentials") = CStr(FALSE)

	If UBound(aUNCPath) > 2 then
		If aUNCPath(0)="" and aUNCPath(1)="" and aUNCPath(2)<>"" and aUNCPath(3)<>"" then
			sValidateUNC = "\\" & aUNCPath(2) & "\" & aUNCPath(3)
			oLogging.CreateEntry "Validate Against UNC: " & sValidateUNC , LogTypeInfo
		End if
	End if

	If not IsEmpty(sValidateDomain) then

		oLogging.CreateEntry "Validate Against Domain: " & sValidateDomain , LogTypeInfo

	ElseIf not IsEmpty(sValidateUNC) then

		sValidateDomain = GetDomainDefault
		oLogging.CreateEntry "Validate Against UNC: " & sValidateUNC , LogTypeInfo
		' Do we need to do any checking for IP address ( as compared to server names )

	Else

		sValidateDomain = GetDomainDefault

	End if

	If UserName.Value = "" and oNetwork.UserName <> "" and oNetwork.UserName <> "SYSTEM" then
		UserName.Value = oNetwork.UserName
	End if

	If oProperties("userdomain") = "" and sValidateDomain <> "" then
		userdomain.Value = sValidateDomain
	ElseIf oproperties("userdomain") = "" and oNetwork.UserDomain <> "" then
		userdomain.Value = oNetwork.UserDomain
	End if

End function

Function ValidateCredentials
	Dim r
	InvalidCredentials.style.display = "none"
	ValidateCredentials = ParseAllWarningLabelsEx(userdomain, username)

	If ValidateCredentials then

		r = CheckCredentials(sValidateUNC, UserName.value, userdomain.Value, userpassword.value)
		If r <> TRUE then
			InvalidCredentials.innerText = "* Invalid credentials: " & r
			InvalidCredentials.style.display = "inline"
			ValidateCredentials = false
		End if
	End if
End Function

Function Create_Summary
	Dim SummaryBuffer
	SummaryBuffer = ""
	'// Pre-requisites
	SummaryBuffer = "Pre-requisite changes:" & vbcrlf

	If (oEnvironment.Item("MDT_INSTALL") = "YES") Then
		SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Install" & " ---> Microsoft Deployment Toolkit 2013" & vbcrlf
	End If
	If (oEnvironment.Item("ADK_INSTALL") = "YES") Then
		SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Install" & " ---> Windows Assessment and Deployment Toolkit" & vbcrlf
	End If
	If (oEnvironment.Item("POWERSHELL_INSTALL") = "YES") Then
		SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Install" & " ---> Windows PowerShell" & vbcrlf
	End If
	If (oEnvironment.Item("POWERSHELL_CONFIG") = "YES") Then
		SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Install" & " ---> Windows PowerShell Execution Policy" & vbcrlf
	End If
	
	'// Deployment Share
	SummaryBuffer = vbcrlf & SummaryBuffer & "Deployment share configuration:" & vbcrlf
	SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Deployment share location: " & oEnvironment.Item("DSFILEPATH") & vbcrlf
	SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Deployment share name: " & oEnvironment.Item("DSSHARENAME") & vbcrlf
	SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Windows source files: " & oEnvironment.Item("OSSOURCEFILEPATH") & vbcrlf
	SummaryBuffer = SummaryBuffer & vbtab & vbtab  & "Import WDS boot media: " & oEnvironment.Item("WDS_CONFIG") & vbcrlf	
	
	'// Device Applications
	SummaryBuffer = vbcrlf & SummaryBuffer & "Device applications:" & vbcrlf
	If (oEnvironment.Item("Surface_Firmware") = "YES") Then
		SummaryBuffer = SummaryBuffer & vbtab & vbtab & "Surface Firmware" & vbcrlf
	End If
	If (oEnvironment.Item("Surface_App") = "YES") Then
		SummaryBuffer = SummaryBuffer & vbtab & vbtab & "Surface App" & vbcrlf
	End If
	
	'// Device Support
	SummaryBuffer = vbcrlf & SummaryBuffer & "Device support for:" & vbcrlf
	If (oEnvironment.Item("SurfacePro3_Drivers") = "YES") Then
		SummaryBuffer = SummaryBuffer & vbtab & vbtab & "Surface Pro 3" & vbcrlf
	End If
	
	SDA_WizardActionSummary.InnerText = trim(SummaryBuffer)
End Function